==> recline-0.0.24.tgz: package/dep/fields.js <==
var sprintf = require('./sprintf');
var valueCondition = '<% if(typeof value == "string"){ print(\'value=\"\'+value+\'\"\') } %>';
var checked = '<% if(typeof checked == "boolean" && checked == true) { print(\'checked="checked"\') } %>'

exports.fields = {
	"label" 		:  '<label for="<%=name%>"><%=label%></label>',
	"invalid"		:  '<span class="error"><%=invalid%></span>',
	"email"			:  sprintf('<input id="<%=name%>" type="email" name="<%=name%>" %s maxlength="255"/>', valueCondition),	
	"textinput"	:  sprintf('<input id="<%=name%>" type="text" name="<%=name%>"	%s maxlength="255"/>', valueCondition),
	"textonly"	:  sprintf('<input id="<%=name%>" type="text" name="<%=name%>"  %s maxlength="255"/>', valueCondition),
	"textarea"	:  sprintf('<textarea id="<%=name%>" name="<%=name%>" %s rows="<%=rows%>" cols="<%=cols%>"></textarea>', valueCondition),
	"roption"		:  sprintf('<input type="radio" name="<%=name%>" %s %s />', valueCondition, checked),
	"cboption"	:  sprintf('<input type="radio" name="<%=name%>" %s %s />', valueCondition, checked),
	"checkbox"	:  sprintf('<input id="<%=name%>" type="checkbox" name="<%=name%>"	%s %s maxlength="255"/>', valueCondition, checked),
	"soption"		:  sprintf('<option %s><%=value%></option>', valueCondition),
	"select"		:  '<select id="<%=name%> name="<%=name%>">'
}

exports.lookup = function(ext, defaultType) {
  defaultType = defaultType || "<input id='<%= name %>' type='text' name='<%= name %>' maxlength='255'/>";

  return (ext in exports.fields)
    ? exports.fields[ext]
    : defaultType;
};

==> recline-0.0.26.tgz: package/dep/fields.js <==
var sprintf = require('./sprintf');
var valueCondition = '<% if(typeof value == "string"){ print(\'value=\"\'+value+\'\"\') } %>';
var checked = '<% if(typeof checked == "boolean" && checked == true) { print(\'checked="checked"\') } %>'

exports.fields = {
	"label" 		:  '<label for="<%=name%>"><%=label%></label>',
	"invalid"		:  '<span class="error"><%=invalid%></span>',
	"email"			:  sprintf('<input id="<%=name%>" type="email" name="<%=name%>" %s maxlength="255"/>', valueCondition),	
	"textinput"	:  sprintf('<input id="<%=name%>" type="text" name="<%=name%>"	%s maxlength="255"/>', valueCondition),
	"textonly"	:  sprintf('<input id="<%=name%>" type="text" name="<%=name%>"  %s maxlength="255"/>', valueCondition),
	"textarea"	:  sprintf('<textarea id="<%=name%>" name="<%=name%>" %s rows="<%=rows%>" cols="<%=cols%>"></textarea>', valueCondition),
	"roption"		:  sprintf('<input type="radio" name="<%=name%>" %s %s />', valueCondition, checked),
	"cboption"	:  sprintf('<input type="checkbox" name="<%=name%>" %s %s />', valueCondition, checked),
	"checkbox"	:  sprintf('<input id="<%=name%>" type="checkbox" name="<%=name%>"	%s %s maxlength="255"/>', valueCondition, checked),
	"soption"		:  sprintf('<option %s><%=value%></option>', valueCondition),
	"select"		:  '<select id="<%=name%> name="<%=name%>">'
}

exports.lookup = function(ext, defaultType) {
  defaultType = defaultType || "<input id='<%= name %>' type='text' name='<%= name %>' maxlength='255'/>";

  return (ext in exports.fields)
    ? exports.fields[ext]
    : defaultType;
};
